@@ -3,7 +3,7 @@
  *				back to source text
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/backend/utils/adt/ruleutils.c,v 1.124 2002/09/19 23:40:56 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/ruleutils.c,v 1.124.2.3 2006/05/21 19:56:40 momjian Exp $
  *
  *	  This software is copyrighted by Jan Wieck - Hamburg.
  *
@@ -688,6 +688,11 @@ pg_get_constraintdef(PG_FUNCTION_ARGS)
 				}
 				appendStringInfo(&buf, " ON DELETE %s", string);
 
+				if (conForm->condeferrable)
+					appendStringInfo(&buf, " DEFERRABLE");
+				if (conForm->condeferred)
+					appendStringInfo(&buf, " INITIALLY DEFERRED");
+
 				break;
 			}
 
@@ -2558,7 +2563,7 @@ get_const_expr(Const *constval, deparse_context *context)
 
 				if (ch == '\'' || ch == '\\')
 				{
-					appendStringInfoChar(buf, '\\');
+					appendStringInfoChar(buf, ch);
 					appendStringInfoChar(buf, ch);
 				}
 				else if (((unsigned char) ch) < ((unsigned char) ' '))
@@ -2946,6 +2951,7 @@ get_opclass_name(Oid opclass, Oid actual_datatype,
 	Form_pg_opclass opcrec;
 	char	   *opcname;
 	char	   *nspname;
+	bool		isvisible;
 
 	/* Domains use their base type's default opclass */
 	if (OidIsValid(actual_datatype))
@@ -2957,11 +2963,16 @@ get_opclass_name(Oid opclass, Oid actual_datatype,
 	if (!HeapTupleIsValid(ht_opc))
 		elog(ERROR, "cache lookup failed for opclass %u", opclass);
 	opcrec = (Form_pg_opclass) GETSTRUCT(ht_opc);
-	if (actual_datatype != opcrec->opcintype || !opcrec->opcdefault)
+
+	/* Must force use of opclass name if not in search path */
+	isvisible = OpclassIsVisible(opclass);
+
+	if (actual_datatype != opcrec->opcintype || !opcrec->opcdefault ||
+		!isvisible)
 	{
 		/* Okay, we need the opclass name.	Do we need to qualify it? */
 		opcname = NameStr(opcrec->opcname);
-		if (OpclassIsVisible(opclass))
+		if (isvisible)
 			appendStringInfo(buf, " %s", quote_identifier(opcname));
 		else
 		{
